@@ -49,6 +49,22 @@ pub fn launch() -> ArgMatches {
                 .long("decor")
                 .help("Decorates the animation with certain, mostly border effects")
         )
+        .arg(
+            Arg::new("wallpaper")
+                .value_parser(NonEmptyStringValueParser::new())
+                .required(false)
+                .short('p')
+                .long("wallpaper")
+                .help("Wallpaper background. Use 'ventura' for built-in, or provide a path to a custom image (PNG, JPEG, TGA)")
+        )
+        .arg(
+            Arg::new("wallpaper-padding")
+                .value_parser(clap::value_parser!(u32).range(1..=500))
+                .default_value("60")
+                .required(false)
+                .long("wallpaper-padding")
+                .help("Padding in pixels around the recording when using --wallpaper (1-500, default: 60)")
+        )
         .arg(
             Arg::new("bg")
                 .value_parser(["white", "black", "transparent"])
@@ -122,11 +138,40 @@ pub fn launch() -> ArgMatches {
                 .default_value("t-rec")
                 .help("to specify the output file (without extension)"),
         )
+        .arg(
+            Arg::new("fps")
+                .value_parser(clap::value_parser!(u8).range(4..=15))
+                .default_value("4")
+                .required(false)
+                .short('f')
+                .long("fps")
+                .help("Capture framerate, 4-15 fps. Higher = smoother animations but larger files"),
+        )
         .arg(
             Arg::new("program")
                 .value_name("shell or program to launch")
                 .value_parser(NonEmptyStringValueParser::new())
                 .required(false)
                 .help("If you want to start a different program than $SHELL you can pass it here. For example '/bin/sh'"),
-        ).get_matches()
+        )
+        .arg(
+            Arg::new("profile")
+                .value_parser(NonEmptyStringValueParser::new())
+                .required(false)
+                .long("profile")
+                .help("Use a named profile from the config file"),
+        )
+        .arg(
+            Arg::new("init-config")
+                .action(ArgAction::SetTrue)
+                .long("init-config")
+                .help("Create a starter config file at ~/.config/t-rec/config.toml"),
+        )
+        .arg(
+            Arg::new("list-profiles")
+                .action(ArgAction::SetTrue)
+                .long("list-profiles")
+                .help("List available profiles from the config file"),
+        )
+        .get_matches()
 }
